@@ -645,7 +645,6 @@ this option is set to yes",
                               ctlfile, err)
                 cls.info('loaded cubicweb-ctl plugin %s', ctlfile)
         for cube in cls.available_cubes():
-            oldpluginfile = join(cls.cube_dir(cube), 'ecplugin.py')
             pluginfile = join(cls.cube_dir(cube), 'ccplugin.py')
             initfile = join(cls.cube_dir(cube), '__init__.py')
             if exists(pluginfile):
@@ -654,14 +653,6 @@ this option is set to yes",
                     cls.info('loaded cubicweb-ctl plugin from %s', cube)
                 except Exception:
                     cls.exception('while loading plugin %s', pluginfile)
-            elif exists(oldpluginfile):
-                warn('[3.6] %s: ecplugin module should be renamed to ccplugin' % cube,
-                     DeprecationWarning)
-                try:
-                    __import__('cubes.%s.ecplugin' % cube)
-                    cls.info('loaded cubicweb-ctl plugin from %s', cube)
-                except Exception:
-                    cls.exception('while loading plugin %s', oldpluginfile)
             elif exists(initfile):
                 try:
                     __import__('cubes.%s' % cube)
@@ -795,13 +786,6 @@ this option is set to yes",
             if exists(sitefile) and not sitefile in self._site_loaded:
                 self._load_site_cubicweb(sitefile)
                 self._site_loaded.add(sitefile)
-            else:
-                sitefile = join(path, 'site_erudi.py')
-                if exists(sitefile) and not sitefile in self._site_loaded:
-                    self._load_site_cubicweb(sitefile)
-                    self._site_loaded.add(sitefile)
-                    self.warning('[3.5] site_erudi.py is deprecated, should be '
-                                 'renamed to site_cubicweb.py')
 
     def _load_site_cubicweb(self, sitefile):
         # XXX extrapath argument to load_module_from_file only in lgc > 0.50.2
@@ -1165,7 +1149,7 @@ the repository',
 
     def _gettext_init(self):
         """set language for gettext"""
-        from cubicweb.gettext import translation
+        from gettext import translation
         path = join(self.apphome, 'i18n')
         for language in self.available_languages():
             self.info("loading language %s", language)
