@@ -118,54 +118,35 @@ class AnyEntity(Entity):
             return self.printable_value(rtype, format='text/plain').lower()
         return value
 
-    # edition helper functions ################################################
-
-    def linked_to(self, rtype, role, remove=True):
-        """if entity should be linked to another using '__linkto' form param for
-        the given relation/role, return eids of related entities
-
-        This method is consuming matching link-to information from form params
-        if `remove` is True (by default). Computed values are stored into a
-        `cw_linkto` attribute, a dictionary with (relation, role) as key and
-        linked eids as value.
-        """
-        try:
-            return self.cw_linkto[(rtype, role)]
-        except AttributeError:
-            self.cw_linkto = {}
-        except KeyError:
-            pass
-        linktos = list(self._cw.list_form_param('__linkto'))
-        linkedto = []
-        for linkto in linktos[:]:
-            ltrtype, eid, ltrole = linkto.split(':')
-            if rtype == ltrtype and role == ltrole:
-                # delete __linkto from form param to avoid it being added as
-                # hidden input
-                if remove:
-                    linktos.remove(linkto)
-                    self._cw.form['__linkto'] = linktos
-                linkedto.append(typed_eid(eid))
-        self.cw_linkto[(rtype, role)] = linkedto
-        return linkedto
-
-    # server side helpers #####################################################
-
-# XXX:  store a reference to the AnyEntity class since it is hijacked in goa
-#       configuration and we need the actual reference to avoid infinite loops
-#       in mro
-ANYENTITY = AnyEntity
 
 def fetch_config(fetchattrs, mainattr=None, pclass=AnyEntity, order='ASC'):
-    if pclass is ANYENTITY:
-        pclass = AnyEntity # AnyEntity and ANYENTITY may be different classes
+    """function to ease basic configuration of an entity class ORM. Basic usage
+    is:
+
+    .. sourcecode:: python
+
+      class MyEntity(AnyEntity):
+
+          fetch_attrs, cw_fetch_order = fetch_config(['attr1', 'attr2'])
+          # uncomment line below if you want the same sorting for 'unrelated' entities
+          # cw_fetch_unrelated_order = cw_fetch_order
+
+    Using this, when using ORM methods retrieving this type of entity, 'attr1'
+    and 'attr2' will be automatically prefetched and results will be sorted on
+    'attr1' ascending (ie the first attribute in the list).
+
+    This function will automatically add to fetched attributes those defined in
+    parent class given using the `pclass` argument.
+
+    Also, You can use `mainattr` and `order` argument to have a different
+    sorting.
+    """
     if pclass is not None:
         fetchattrs += pclass.fetch_attrs
     if mainattr is None:
         mainattr = fetchattrs[0]
     @classmethod
-    def fetch_order(cls, attr, var):
+    def fetch_order(cls, select, attr, var):
         if attr == mainattr:
-            return '%s %s' % (var, order)
-        return None
+            select.add_sort_var(var, order=='ASC')
     return fetchattrs, fetch_order
