@@ -26,30 +26,27 @@ from cubicweb.entities import AnyEntity, fetch_config
 
 class CWGroup(AnyEntity):
     __regid__ = 'CWGroup'
-    fetch_attrs, fetch_order = fetch_config(['name'])
-    fetch_unrelated_order = fetch_order
+    fetch_attrs, cw_fetch_order = fetch_config(['name'])
+    cw_fetch_unrelated_order = cw_fetch_order
 
-    def grant_permission(self, entity, pname, plabel=None):
-        """grant local `pname` permission on `entity` to this group using
-        :class:`CWPermission`.
+    def dc_long_title(self):
+        name = self.name
+        trname = self._cw._(name)
+        if trname != name:
+            return '%s (%s)' % (name, trname)
+        return name
 
-        If a similar permission already exists, add the group to it, else create
-        a new one.
-        """
-        if not self._cw.execute(
-            'SET X require_group G WHERE E eid %(e)s, G eid %(g)s, '
-            'E require_permission X, X name %(name)s, X label %(label)s',
-            {'e': entity.eid, 'g': self.eid,
-             'name': pname, 'label': plabel}):
-            self._cw.create_entity('CWPermission', name=pname, label=plabel,
-                                   require_group=self,
-                                   reverse_require_permission=entity)
+    @cached
+    def num_users(self):
+        """return the number of users in this group"""
+        return self._cw.execute('Any COUNT(U) WHERE U in_group G, G eid %(g)s',
+                                {'g': self.eid})[0][0]
 
 
 class CWUser(AnyEntity):
     __regid__ = 'CWUser'
-    fetch_attrs, fetch_order = fetch_config(['login', 'firstname', 'surname'])
-    fetch_unrelated_order = fetch_order
+    fetch_attrs, cw_fetch_order = fetch_config(['login', 'firstname', 'surname'])
+    cw_fetch_unrelated_order = cw_fetch_order
 
     # used by repository to check if  the user can log in or not
     AUTHENTICABLE_STATES = ('activated',)
@@ -139,18 +136,6 @@ class CWUser(AnyEntity):
             return False
     owns = cached(owns, keyarg=1)
 
-    def has_permission(self, pname, contexteid=None):
-        rql = 'Any P WHERE P is CWPermission, U eid %(u)s, U in_group G, '\
-              'P name %(pname)s, P require_group G'
-        kwargs = {'pname': pname, 'u': self.eid}
-        if contexteid is not None:
-            rql += ', X require_permission P, X eid %(x)s'
-            kwargs['x'] = contexteid
-        try:
-            return self._cw.execute(rql, kwargs)
-        except Unauthorized:
-            return False
-
     # presentation utilities ##################################################
 
     def name(self):
