@@ -49,7 +49,7 @@ class MetadataTC(BaseEntityTC):
         self.assertEqual(entity.dc_creator(), u'member')
 
     def test_type(self):
-        self.assertEqual(self.member.dc_type(), 'cwuser')
+        self.assertEqual(self.member.dc_type(), 'CWUser')
 
     def test_entity_meta_attributes(self):
         # XXX move to yams
@@ -88,10 +88,10 @@ class CWUserTC(BaseEntityTC):
 
     def test_matching_groups(self):
         e = self.execute('CWUser X WHERE X login "admin"').get_entity(0, 0)
-        self.failUnless(e.matching_groups('managers'))
-        self.failIf(e.matching_groups('xyz'))
-        self.failUnless(e.matching_groups(('xyz', 'managers')))
-        self.failIf(e.matching_groups(('xyz', 'abcd')))
+        self.assertTrue(e.matching_groups('managers'))
+        self.assertFalse(e.matching_groups('xyz'))
+        self.assertTrue(e.matching_groups(('xyz', 'managers')))
+        self.assertFalse(e.matching_groups(('xyz', 'abcd')))
 
     def test_dc_title_and_name(self):
         e = self.execute('CWUser U WHERE U login "member"').get_entity(0, 0)
@@ -131,12 +131,12 @@ class InterfaceTC(CubicWebTC):
         self.vreg['etypes'].initialization_completed()
         MyUser_ = self.vreg['etypes'].etype_class('CWUser')
         # a copy is done systematically
-        self.failUnless(issubclass(MyUser_, MyUser))
-        self.failUnless(implements(MyUser_, IMileStone))
-        self.failUnless(implements(MyUser_, ICalendarable))
+        self.assertTrue(issubclass(MyUser_, MyUser))
+        self.assertTrue(implements(MyUser_, IMileStone))
+        self.assertTrue(implements(MyUser_, ICalendarable))
         # original class should not have beed modified, only the copy
-        self.failUnless(implements(MyUser, IMileStone))
-        self.failIf(implements(MyUser, ICalendarable))
+        self.assertTrue(implements(MyUser, IMileStone))
+        self.assertFalse(implements(MyUser, ICalendarable))
 
 
 class SpecializedEntityClassesTC(CubicWebTC):
@@ -149,7 +149,7 @@ class SpecializedEntityClassesTC(CubicWebTC):
     def test_etype_class_selection_and_specialization(self):
         # no specific class for Subdivisions, the default one should be selected
         eclass = self.select_eclass('SubDivision')
-        self.failUnless(eclass.__autogenerated__)
+        self.assertTrue(eclass.__autogenerated__)
         #self.assertEqual(eclass.__bases__, (AnyEntity,))
         # build class from most generic to most specific and make
         # sure the most specific is always selected
@@ -159,8 +159,8 @@ class SpecializedEntityClassesTC(CubicWebTC):
                 __regid__ = etype
             self.vreg.register(Foo)
             eclass = self.select_eclass('SubDivision')
-            self.failUnless(eclass.__autogenerated__)
-            self.failIf(eclass is Foo)
+            self.assertTrue(eclass.__autogenerated__)
+            self.assertFalse(eclass is Foo)
             if etype == 'SubDivision':
                 self.assertEqual(eclass.__bases__, (Foo,))
             else:
