@@ -34,6 +34,7 @@ from logilab.common.changelog import Version
 
 from cubicweb import ConfigurationError, ExecutionError
 from cubicweb.cwconfig import CubicWebConfiguration as cwcfg
+from cubicweb.toolsutils import show_diffs
 
 def filter_scripts(config, directory, fromversion, toversion, quiet=True):
     """return a list of paths of migration files to consider to upgrade
@@ -269,10 +270,7 @@ type "exit" or Ctrl-D to quit the shell and resume operation"""
         def unicode_raw_input(prompt):
             return unicode(raw_input(prompt), sys.stdin.encoding)
         interact(banner, readfunc=unicode_raw_input, local=local_ctx)
-        try:
-            readline.write_history_file(histfile)
-        except IOError:
-            pass
+        readline.write_history_file(histfile)
         # delete instance's confirm attribute to avoid questions
         del self.confirm
         self.need_wrap = True
@@ -414,14 +412,12 @@ type "exit" or Ctrl-D to quit the shell and resume operation"""
         basecubes = [c for c in origcubes if not c in toremove]
         self.config._cubes = tuple(self.config.expand_cubes(basecubes))
         removed = [p for p in origcubes if not p in self.config._cubes]
-        if not cube in removed and cube in origcubes:
+        if not cube in removed:
             raise ConfigurationError("can't remove cube %s, "
                                      "used as a dependency" % cube)
         return removed
 
     def rewrite_configuration(self):
-        # import locally, show_diffs unavailable in gae environment
-        from cubicweb.toolsutils import show_diffs
         configfile = self.config.main_config_file()
         if self._option_changes:
             read_old_config(self.config, self._option_changes, configfile)
