@@ -207,7 +207,7 @@ class RQLRewriter(object):
             vi = {}
             self.varinfos.append(vi)
             try:
-                vi['const'] = typed_eid(selectvar) # XXX gae
+                vi['const'] = typed_eid(selectvar)
                 vi['rhs_rels'] = vi['lhs_rels'] = {}
             except ValueError:
                 try:
@@ -660,7 +660,7 @@ class RQLRewriter(object):
             selectvar, index = self.revvarmap[node.name]
             vi = self.varinfos[index]
             if vi.get('const') is not None:
-                return n.Constant(vi['const'], 'Int') # XXX gae
+                return n.Constant(vi['const'], 'Int')
             return n.VariableRef(stmt.get_variable(selectvar))
         vname_or_term = self._get_varname_or_term(node.name)
         if isinstance(vname_or_term, basestring):
