@@ -481,9 +481,9 @@ class ResultSet(object):
             eschema = entity.e_schema
             eid_col, attr_cols, rel_cols = self._rset_structure(eschema, col)
             entity.eid = rowvalues[eid_col]
-            for attr, col_idx in attr_cols.items():
+            for attr, col_idx in attr_cols.iteritems():
                 entity.cw_attr_cache[attr] = rowvalues[col_idx]
-            for (rtype, role), col_idx in rel_cols.items():
+            for (rtype, role), col_idx in rel_cols.iteritems():
                 value = rowvalues[col_idx]
                 if value is None:
                     if role == 'subject':
@@ -695,7 +695,7 @@ def attr_desc_iterator(select, selectidx, rootidx):
             continue
         if rootvar.name == rootmainvar.name:
             continue
-        if select is not rootselect and isinstance(rootvar, nodes.ColumnAlias):
+        if select is not rootselect:
             term = select.selection[root.subquery_selection_index(select, i)]
         var = _get_variable(term)
         if var is None:
