@@ -25,7 +25,6 @@ __docformat__ = "restructuredtext en"
 
 from itertools import repeat
 
-from logilab.common.cache import Cache
 from logilab.common.compat import any
 from rql import RQLSyntaxError
 from rql.stmts import Union, Select
@@ -36,6 +35,7 @@ from cubicweb import ValidationError, Unauthorized, QueryError, UnknownEid
 from cubicweb import server, typed_eid
 from cubicweb.rset import ResultSet
 
+from cubicweb.utils import QueryCache
 from cubicweb.server.utils import cleanup_solutions
 from cubicweb.server.rqlannotation import SQLGenAnnotator, set_qdata
 from cubicweb.server.ssplanner import READ_ONLY_RTYPES, add_types_restriction
@@ -599,7 +599,7 @@ class QuerierHelper(object):
         self.schema = schema
         repo = self._repo
         # rql st and solution cache.
-        self._rql_cache = Cache(repo.config['rql-cache-size'])
+        self._rql_cache = QueryCache(repo.config['rql-cache-size'])
         # rql cache key cache. Don't bother using a Cache instance: we should
         # have a limited number of queries in there, since there are no entries
         # in this cache for user queries (which have no args)
