@@ -71,13 +71,6 @@ class AttrDescIteratorTC(TestCase):
         result = list(attr_desc_iterator(select, col, 2))
         self.assertEqual(result, [])
 
-    def test_subquery_callfunc_2(self):
-        rql = ('Any X,S,L WHERE X in_state S WITH X, L BEING (Any X,MAX(L) GROUPBY X WHERE X is CWUser, T wf_info_for X, T creation_date L)')
-        rqlst = parse(rql)
-        select, col = rqlst.locate_subquery(0, 'CWUser', None)
-        result = list(attr_desc_iterator(select, col, 0))
-        self.assertEqual(result, [(1, 'in_state', 'subject')])
-
 
 class ResultSetTC(CubicWebTC):
 
@@ -430,7 +423,7 @@ class ResultSetTC(CubicWebTC):
     def test_entities(self):
         rset = self.execute('Any U,G WHERE U in_group G')
         # make sure we have at least one element
-        self.failUnless(rset)
+        self.assertTrue(rset)
         self.assertEqual(set(e.e_schema.type for e in rset.entities(0)),
                           set(['CWUser',]))
         self.assertEqual(set(e.e_schema.type for e in rset.entities(1)),
@@ -439,7 +432,7 @@ class ResultSetTC(CubicWebTC):
     def test_iter_rows_with_entities(self):
         rset = self.execute('Any U,UN,G,GN WHERE U in_group G, U login UN, G name GN')
         # make sure we have at least one element
-        self.failUnless(rset)
+        self.assertTrue(rset)
         out = list(rset.iter_rows_with_entities())[0]
         self.assertEqual( out[0].login, out[1] )
         self.assertEqual( out[2].name, out[3] )
@@ -486,6 +479,5 @@ class ResultSetTC(CubicWebTC):
         self.assertIsInstance(str(rset), basestring)
         self.assertEqual(len(str(rset).splitlines()), 1)
 
-
 if __name__ == '__main__':
     unittest_main()
