@@ -1,4 +1,4 @@
-# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of CubicWeb.
@@ -118,7 +118,8 @@ class RQLBoxTemplate(BoxTemplate):
     related to the current result set.
     """
 
-    rql  = None
+    # to be defined in concrete classes
+    rql = title = None
 
     def to_display_rql(self):
         assert self.rql is not None, self.__regid__
@@ -168,7 +169,7 @@ class EditRelationBoxTemplate(EditRelationMixIn, EntityBoxTemplate):
     subclasses should define at least id, rtype and target
     class attributes.
     """
-
+    rtype = None
     def cell_call(self, row, col, view=None, **kwargs):
         self._cw.add_js('cubicweb.ajax.js')
         entity = self.cw_rset.get_entity(row, col)
