@@ -167,7 +167,7 @@ errorMsgBgImg = 'url("error.png") 100% 50% no-repeat'
 errorMsgColor = '#ed0d0d'
 
 # facets
-facet_titleFont = 'bold 100% Georgia'
+facet_titleFont = 'bold SansSerif'
 facet_overflowedHeight = '12em'
-
-
+# the above minus 1
+facet_overflowedHeightWithLogicalSelector = '11em'
