@@ -20,6 +20,8 @@
 __docformat__ = "restructuredtext en"
 _ = unicode
 
+from warnings import warn
+
 from logilab.mtconverter import xml_escape
 
 from cubicweb.appobject import objectify_selector
@@ -28,9 +30,14 @@ from cubicweb.selectors import (non_final_entity, multi_lines_rset,
 from cubicweb.utils import json_dumps
 from cubicweb.web import component, facet as facetbase
 
-def facets(req, rset, context, mainvar=None):
+def facets(req, rset, context, mainvar=None, **kwargs):
     """return the base rql and a list of widgets for facets applying to the
-    given rset/context (cached version)
+    given rset/context (cached version of :func:`_facet`)
+
+    :param req: A :class:`~cubicweb.req.RequestSessionBase` object
+    :param rset: A :class:`~cubicweb.rset.ResultSet`
+    :param context: A string that match the ``__regid__`` of a ``FacetFilter``
+    :param mainvar: A string that match a select var from the rset
     """
     try:
         cache = req.__rset_facets
@@ -39,26 +46,35 @@ def facets(req, rset, context, mainvar=None):
     try:
         return cache[(rset, context, mainvar)]
     except KeyError:
-        facets = _facets(req, rset, context, mainvar)
+        facets = _facets(req, rset, context, mainvar, **kwargs)
         cache[(rset, context, mainvar)] = facets
         return facets
 
-def _facets(req, rset, context, mainvar):
+def _facets(req, rset, context, mainvar, **kwargs):
     """return the base rql and a list of widgets for facets applying to the
     given rset/context
+
+    :param req: A :class:`~cubicweb.req.RequestSessionBase` object
+    :param rset: A :class:`~cubicweb.rset.ResultSet`
+    :param context: A string that match the ``__regid__`` of a ``FacetFilter``
+    :param mainvar: A string that match a select var from the rset
     """
+    ### initialisation
     # XXX done by selectors, though maybe necessary when rset has been hijacked
     # (e.g. contextview_selector matched)
     origqlst = rset.syntax_tree()
     # union not yet supported
     if len(origqlst.children) != 1:
+        req.debug('facette disabled on union request %s', origqlst)
         return None, ()
     rqlst = origqlst.copy()
     select = rqlst.children[0]
     filtered_variable, baserql = facetbase.init_facets(rset, select, mainvar)
-    wdgs = [(facet, facet.get_widget()) for facet in req.vreg['facets'].poss_visible_objects(
-        req, rset=rset, rqlst=origqlst, select=select, context=context,
-        filtered_variable=filtered_variable)]
+    ### Selection
+    possible_facets = req.vreg['facets'].poss_visible_objects(
+        req, rset=rset, rqlst=origqlst, select=select,
+        context=context, filtered_variable=filtered_variable, **kwargs)
+    wdgs = [(facet, facet.get_widget()) for facet in possible_facets]
     return baserql, [wdg for facet, wdg in wdgs if wdg is not None]
 
 
@@ -73,15 +89,15 @@ def contextview_selector(cls, req, rset=None, row=None, col=None, view=None,
         rset = getcontext()[0]
         if rset is None or rset.rowcount < 2:
             return 0
-        wdgs = facets(req, rset, cls.__regid__)[1]
+        wdgs = facets(req, rset, cls.__regid__, view=view)[1]
         return len(wdgs)
     return 0
 
 @objectify_selector
-def has_facets(cls, req, rset=None, mainvar=None, **kwargs):
+def has_facets(cls, req, rset=None, **kwargs):
     if rset is None or rset.rowcount < 2:
         return 0
-    wdgs = facets(req, rset, cls.__regid__, mainvar)[1]
+    wdgs = facets(req, rset, cls.__regid__, **kwargs)[1]
     return len(wdgs)
 
 
@@ -94,15 +110,50 @@ def filter_hiddens(w, baserql, wdgs, **kwargs):
 
 
 class FacetFilterMixIn(object):
+    """Mixin Class to generate Facet Filter Form
+
+    To generate the form, you need to explicitly call the following method:
+
+    .. automethod:: generate_form
+
+    The most useful function to override is:
+
+    .. automethod:: layout_widgets
+    """
+
     needs_js = ['cubicweb.ajax.js', 'cubicweb.facets.js']
     needs_css = ['cubicweb.facets.css']
     roundcorners = True
 
-    def generate_form(self, w, rset, divid, vid, vidargs,
-                      paginate=False, cssclass='', **hiddens):
-        """display a form to filter some view's content"""
-        mainvar = self.cw_extra_kwargs.get('mainvar')
-        baserql, wdgs = facets(self._cw, rset, self.__regid__, mainvar)
+    def generate_form(self, w, rset, divid, vid, vidargs=None, mainvar=None,
+                      paginate=False, cssclass='', hiddens=None, **kwargs):
+        """display a form to filter some view's content
+
+        :param w:        Write function
+
+        :param rset:     ResultSet to be filtered
+
+        :param divid:    Dom ID of the div where the rendering of the view is done.
+        :type divid:     string
+
+        :param vid:      ID of the view display in the div
+        :type vid:       string
+
+        :param paginate: Is the view paginated ?
+        :type paginate:  boolean
+
+        :param cssclass: Additional css classes to put on the form.
+        :type cssclass:  string
+
+        :param hiddens:  other hidden parametters to include in the forms.
+        :type hiddens:   dict from extra keyword argument
+        """
+        # XXX Facet.context property hijacks an otherwise well-behaved
+        #     vocabulary with its own notions
+        #     Hence we whack here to avoid a clash
+        kwargs.pop('context', None)
+        baserql, wdgs = facets(self._cw, rset, context=self.__regid__,
+                               mainvar=mainvar, **kwargs)
         assert wdgs
         self._cw.add_js(self.needs_js)
         self._cw.add_css(self.needs_css)
@@ -111,12 +162,18 @@ class FacetFilterMixIn(object):
         if self.roundcorners:
             self._cw.html_headers.add_onload(
                 'jQuery(".facet").corner("tl br 10px");')
-        # drop False / None values from vidargs
+        if vidargs is not None:
+            warn("[3.14] vidargs is deprecated. Maybe you're using some TableView?",
+                 DeprecationWarning, stacklevel=2)
+        else:
+            vidargs = {}
         vidargs = dict((k, v) for k, v in vidargs.iteritems() if v)
         facetargs = xml_escape(json_dumps([divid, vid, paginate, vidargs]))
         w(u'<form id="%sForm" class="%s" method="post" action="" '
           'cubicweb:facetargs="%s" >' % (divid, cssclass, facetargs))
         w(u'<fieldset>')
+        if hiddens is None:
+            hiddens = {}
         if mainvar:
             hiddens['mainvar'] = mainvar
         filter_hiddens(w, baserql, wdgs, **hiddens)
@@ -142,7 +199,7 @@ class FacetFilterMixIn(object):
         """sort widgets: by default sort by widget height, then according to
         widget.order (the original widgets order)
         """
-        return sorted(wdgs, key=lambda x: x.height())
+        return sorted(wdgs, key=lambda x: x.height)
 
     def layout_widgets(self, w, wdgs):
         """layout widgets: by default simply render each of them
@@ -177,8 +234,8 @@ class FilterBox(FacetFilterMixIn, component.CtxComponent):
         for param in ('subvid', 'vtitle'):
             if param in req.form:
                 hiddens[param] = req.form[param]
-        self.generate_form(w, rset, divid, vid, self.vidargs(),
-                           paginate=paginate, **hiddens)
+        self.generate_form(w, rset, divid, vid, paginate=paginate,
+                           hiddens=hiddens, **self.cw_extra_kwargs)
 
     def _get_context(self):
         view = self.cw_extra_kwargs.get('view')
@@ -208,12 +265,6 @@ class FilterBox(FacetFilterMixIn, component.CtxComponent):
                 req._('bookmark this search'))
         return self.bk_linkbox_template % bk_link
 
-    def vidargs(self):
-        """this method returns the list of extra arguments that should be used
-        by the filter or the view using it
-        """
-        return {}
-
 
 from cubicweb.view import AnyRsetView
 
@@ -222,11 +273,11 @@ class FilterTable(FacetFilterMixIn, AnyRsetView):
     __select__ = has_facets()
     compact_layout_threshold = 5
 
-    def call(self, vid, divid, vidargs, cssclass=''):
-        self.generate_form(self.w, self.cw_rset, divid, vid, vidargs,
-                           cssclass=cssclass, fromformfilter='1',
-                           # divid=divid XXX
-                           )
+    def call(self, vid, divid, vidargs=None, cssclass=''):
+        hiddens = self.cw_extra_kwargs.setdefault('hiddens', {})
+        hiddens['fromformfilter'] = '1'
+        self.generate_form(self.w, self.cw_rset, divid, vid, vidargs=vidargs,
+                           cssclass=cssclass, **self.cw_extra_kwargs)
 
     def _simple_horizontal_layout(self, w, wdgs):
         w(u'<table class="filter">\n')
@@ -240,7 +291,7 @@ class FilterTable(FacetFilterMixIn, AnyRsetView):
 
     def layout_widgets(self, w, wdgs):
         """layout widgets: put them in a table where each column should have
-        sum(wdg.height()) < wdg_stack_size.
+        sum(wdg.height) < wdg_stack_size.
         """
         if len(wdgs) < self.compact_layout_threshold:
             self._simple_horizontal_layout(w, wdgs)
@@ -248,10 +299,10 @@ class FilterTable(FacetFilterMixIn, AnyRsetView):
         w(u'<table class="filter">\n')
         widget_queue = []
         queue_height = 0
-        wdg_stack_size = max(wdgs, key=lambda wdg:wdg.height()).height()
+        wdg_stack_size = max(wdgs, key=lambda wdg:wdg.height).height
         w(u'<tr>\n')
         for wdg in wdgs:
-            height = wdg.height()
+            height = wdg.height
             if queue_height + height <= wdg_stack_size:
                 widget_queue.append(wdg)
                 queue_height += height
