@@ -143,13 +143,13 @@ class SecurityViewMixIn(object):
 class SchemaView(tabs.TabsMixin, StartupView):
     """display schema information (graphically, listing tables...) in tabs"""
     __regid__ = 'schema'
-    title = _('instance schema')
+    title = _('data model schema')
     tabs = [_('schema-diagram'), _('schema-entity-types'),
             _('schema-relation-types')]
     default_tab = 'schema-diagram'
 
     def call(self):
-        self.w(u'<h1>%s</h1>' % self._cw._('Schema of the data model'))
+        self.w(u'<h1>%s</h1>' % self._cw._(self.title))
         self.render_tabs(self.tabs, self.default_tab)
 
 
@@ -676,14 +676,6 @@ class RQLExpressionIBreadCrumbsAdapter(ibreadcrumbs.IBreadCrumbsAdapter):
     def parent_entity(self):
         return self.entity.expression_of
 
-class CWPermissionIBreadCrumbsAdapter(ibreadcrumbs.IBreadCrumbsAdapter):
-    __select__ = is_instance('CWPermission')
-    def parent_entity(self):
-        # XXX useless with permission propagation
-        permissionof = getattr(self.entity, 'reverse_require_permission', ())
-        if len(permissionof) == 1:
-            return permissionof[0]
-
 
 # misc: facets, actions ########################################################
 
@@ -697,7 +689,7 @@ class ViewSchemaAction(action.Action):
     __regid__ = 'schema'
     __select__ = yes()
 
-    title = _("data model schema")
+    title = _('data model schema')
     order = 30
     category = 'manage'
 
