@@ -1,4 +1,4 @@
-# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of CubicWeb.
@@ -15,9 +15,8 @@
 #
 # You should have received a copy of the GNU Lesser General Public License along
 # with CubicWeb.  If not, see <http://www.gnu.org/licenses/>.
-"""xbel views
+"""xbel views"""
 
-"""
 __docformat__ = "restructuredtext en"
 _ = unicode
 
@@ -30,7 +29,7 @@ from cubicweb.web.views.xmlrss import XMLView
 
 class XbelView(XMLView):
     __regid__ = 'xbel'
-    title = _('xbel')
+    title = _('xbel export')
     templatable = False
     content_type = 'text/xml' #application/xbel+xml
 
